'use strict';


const ContentType = {
  TextHTML: 'text/html',
  TextPlain: 'text/plain',
  ApplicationForm: 'application/x-www-form-urlencoded',
  ApplicationJson: 'application/json',
};

// Supported encoding types
const EncodingType = {
  Brotli: 'br',
  Gzip: 'gzip',
  XGzip: 'x-gzip',
  Identity: 'identity',
};

// Filename suffixes for serving pre-encoded files
const EncodingTypeSuffix = {
  [EncodingType.Brotli]: '.br',
  [EncodingType.Gzip]: '.gz',
  [EncodingType.XGzip]: '.gz',
};

const ErrorResponse = {
  BadRequest: {
    statusCode: 400,
    errorMessage: 'Bad Request',
  },
  Unauthorized: {
    statusCode: 401,
    errorMessage: 'Unauthorized',
  },
  Forbidden: {
    statusCode: 403,
    errorMessage: 'Forbidden',
  },
  ReallyForbidden: {
    statusCode: 403,
    errorMessage: 'F̦̩̫̼͔̫͓̃ͤ̈̆̀͑o̖̟͙̫̯̗̳̽ͦ̆́ͨr̩͉̰̗͉b̬̂͘į̟̬̓d͂͗҉̟͈̜͙ͅd͎̜̺̝͇͑̒̋̾ë̴̳̺͓̦̘́ͮ̈́ǹ͈̦̫̙',
  },
  NotFound: {
    statusCode: 404,
    errorMessage: 'Not Found',
  },
  MethodNotAllowed: {
    statusCode: 405,
    errorMessage: 'Method Not Allowed',
  },
  NotAcceptable: {
    statusCode: 406,
    errorMessage: 'Not Acceptable',
  },
  Gone: {
    statusCode: 410,
    errorMessage: 'Gone',
  },
  RequestEntityTooLarge: {
    statusCode: 413,
    errorMessage: 'Request Entity Too Large',
  },
  UnsupportedMediaType: {
    statusCode: 415,
    errorMessage: 'Unsupported Media Type',
  },
  InternalServerError: {
    statusCode: 500,
    errorMessage: 'Internal Server Error',
  },
};

const ErrorResponseDefaultProxy = new Proxy(ErrorResponse, {
  get: (target, property) => {
    // eslint-disable-next-line security/detect-object-injection
    return (property in target) ? target[property] : {
      errorMessage: `undefined error response '${property}'`,
    };
  },
});

const Header = {
  Accept: 'Accept',
  AcceptEncoding: 'Accept-Encoding',
  CacheControl: 'Cache-Control',
  ContentEncoding: 'Content-Encoding',
  ContentLength: 'Content-Length',
  ContentType: 'Content-Type',
  ETag: 'ETag',
  IfModifiedSince: 'If-Modified-Since',
  IfNoneMatch: 'If-None-Match',
  LastModified: 'Last-Modified',
  Location: 'Location',
  RequestId: 'Request-ID',
  Vary: 'Vary',
  XCorrelationId: 'X-Correlation-ID',
  XForwardedFor: 'X-Forwarded-For',
  XForwardedProto: 'X-Forwarded-Proto',
  XRealIP: 'X-Real-IP',
  XRequestId: 'X-Request-ID',
};

module.exports = {
  ContentType,
  EncodingType,
  EncodingTypeSuffix,
  ErrorResponse: ErrorResponseDefaultProxy,
  Header,
};
